@@ -1,2 +1,2 @@
 from .plateinfo_and_samplesheet import print_plate_info, make_sample_sheet
-from .demultiplex import demultiplex_pipeline
+from .demultiplex import demultiplex_pipeline, update_snakemake
