@@ -27,7 +27,7 @@ STAMPEDE2_QUEUES = {
     'long': 2,
     'flat-quadrant': 5,
     'skx-dev': 1,
-    'skx-normal': 25,
+    'skx-normal': 20,
     'skx-large': 3
 }
 
@@ -96,16 +96,25 @@ def submit_sbatch(job_script_path):
     -------
 
     """
-    p = subprocess.run(['sbatch', str(job_script_path)],
-                       check=True,
-                       encoding='utf8',
-                       stdout=subprocess.PIPE)
-    job_id = get_job_id(p.stdout)
-    print(f'Submit job script: {job_script_path}. Job ID is {job_id}.')
+    try:
+        p = subprocess.run(['sbatch', str(job_script_path)],
+                           check=True,
+                           encoding='utf8',
+                           stdout=subprocess.PIPE,
+                           stderr=subprocess.PIPE)
+        job_id = get_job_id(p.stdout)
+        print(f'Submit job script: {job_script_path}. Job ID is {job_id}.')
+    except subprocess.CalledProcessError as e:
+        print('sbatch STDOUT')
+        print(e.stdout)
+        print('sbatch STDERR')
+        print(e.stderr)
+        print('sbatch submission failed, see information above.')
+        raise e
     return job_id
 
 
-def squeue():
+def squeue(partition):
     """
     check current running job
 
@@ -154,7 +163,13 @@ def squeue():
         records.append(record)
     squeue_df = pd.DataFrame(records[1:],
                              columns=records[0]).set_index('JOBID')
-    return squeue_df
+    total_job = squeue_df.shape[0]
+    try:
+        squeue_df = squeue_df[squeue_df['PARTITION'].str.lower() == partition.lower()].copy()
+        return squeue_df, total_job
+    except KeyError:
+        print(squeue_df)
+        return squeue_df, total_job
 
 
 def make_sbatch_script_files(commands, sbatch_dir, name_prefix, queue, time_str, email, email_type):
@@ -301,7 +316,7 @@ def sbatch_submitter(project_name, command_file_path, working_dir, time_str, que
                 break
             # squeue and update running job status
             try:
-                squeue_df = squeue()
+                squeue_df, total_job = squeue(partition=queue)
                 squeue_fail = 0
             except Exception as e:
                 print('Squeue parser raised an error, will retry after 150s.')
@@ -310,7 +325,8 @@ def sbatch_submitter(project_name, command_file_path, working_dir, time_str, que
                     raise e
                 time.sleep(150)
                 continue
-            remaining_slots = max_jobs - squeue_df.shape[0]
+            # queue limit and total job limit both apply
+            remaining_slots = min((max_jobs - squeue_df.shape[0], 50 - total_job))
             # the max_jobs is apply to user level, not to the current submitter level
             if remaining_slots > 0:
                 # things are getting done, weak up
